import { createApp } from 'vue'
import { createPinia } from 'pinia'
import './app.scss'
// NutUI样式导入
import '@nutui/nutui-taro/dist/style.css'
import './assets/styles/nutui-custom.scss'
import { useTabBarStore } from './stores/tabbar'
import { useUserStore } from './stores/user'

const App = createApp({
  // 入口组件不需要实现render方法，即使实现了也会被忽略
  onLaunch() {
    if (process.env.TARO_ENV === 'weapp') {
      const Taro = require('@tarojs/taro')
      Taro.cloud.init({
        // 使用默认环境（自动创建，无需认证）
        env: Taro.cloud.DYNAMIC_CURRENT_ENV, 
        traceUser: true
      })
      console.log('已启用微信云开发默认环境')
    }
    
    // 当小程序初始化完成时
    const tabBarStore = useTabBarStore()
    const userStore = useUserStore()
    
    // 初始化 TabBar 状态
    tabBarStore.updateSelected()
    
    // 获取用户信息
    userStore.initUser()
  },
  onShow(options) {
    console.log('App onShow', options)
    // 当小程序启动或从后台进入前台显示时
    const tabBarStore = useTabBarStore()
    tabBarStore.updateSelected()
  },
})

const pinia = createPinia()
App.use(pinia)

export default App